# `debugger`

```sh
rai debugger
```

Open the RelationalAI debugger.

Invoke `rai debugger` from the same directory from which you execute your project.
As your project runs, debugging information is emitted to a `debug.jsonl` file in your current working directory.
The contents of this file are read by a local web server which you can view at `http://localhost:8080`.

The debugger shows the RelationalAI graph queries generated by your Python query builder code
and is primarily intended for internal use.
